use sea_orm_migration::prelude::*;

use super::m20230204_011034_create_posts::Post;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(PostBlock::Table)
                    .if_not_exists()
                    .col(
                            ColumnDef::new(PostBlock::Id)
                            .string()
                            .not_null()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(PostBlock::Owner).string().not_null())
                    .col(ColumnDef::new(PostBlock::Order).integer().not_null())
                    .col(ColumnDef::new(PostBlock::Type).string().not_null())
                    .col(ColumnDef::new(PostBlock::Content).string().not_null())
                    .foreign_key(ForeignKey::create()
                                    .name("fk-post_blocks-posts")
                                    .from(PostBlock::Table, PostBlock::Owner)
                                    .to(Post::Table, Post::Id)
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(PostBlock::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
pub enum PostBlock {
    Table,
    Id,
    Owner,
    Order,
    Type,
    Content
}
