use sea_orm_migration::prelude::*;

use crate::m20230204_001022_create_pages::Page;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(PageBlock::Table)
                    .if_not_exists()
                    .col(
                            ColumnDef::new(PageBlock::Id)
                            .string()
                            .not_null()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(PageBlock::Owner).string().not_null())
                    .col(ColumnDef::new(PageBlock::Order).integer().not_null())
                    .col(ColumnDef::new(PageBlock::Type).string().not_null())
                    .col(ColumnDef::new(PageBlock::Content).string().not_null())
                    .foreign_key(ForeignKey::create()
                                    .name("fk-page_blocks-posts")
                                    .from(PageBlock::Table, PageBlock::Owner)
                                    .to(Page::Table, Page::Id)
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(PageBlock::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
pub enum PageBlock {
    Table,
    Id,
    Owner,
    Order,
    Type,
    Content
}
